==> redquicklib-1.289.0.tgz: package/lib/components/reactnativelogin.js <==
'use strict';
import * as UIA from '../actions/uiActions';
import React, { Component } from 'react';
import {
    AppRegistry,
    StyleSheet,
    Text,
    WebView,
    Linking,
    LinkingIOS,
    Platform,
    View,
    AsyncStorage
} from 'react-native';
var libSafariView = require("react-native-safari-view");
var SafariView = libSafariView.default;
import * as Titles from '../titles';
import * as Common from '../screens/customer/common';
import WaitBall from './waitball';
// Change these to reflect


export default class ReactNativeLogin extends Component {
    constructor(props) {
        super(props);

        this.state = {
            loggedIn: false,
            loadedCookie: false
        };
    }
    getAccessToken(evt) {
        if (evt && evt.url) {
            var accessToken = evt.url.split('access=')[1];
            return accessToken;
        }
    }
    componentWillMount() {
        var me = this;
        this._loadInitialState();
        this.props.loginUrl().then(loginUrl => {

            UIA.log('adding linking listener');
            Linking.addEventListener('url', (evt) => {
                if (evt && evt.url) {
                    UIA.log(evt.url)
                    this.props.ui('URL_', evt.url);
                    var accessToken = me.getAccessToken(evt); //.url.split('access=')[1];
                    if (accessToken) {
                        if (this.props.onAuthentification) {
                            this.props.onAuthentification(accessToken);
                            if (Platform.OS === 'ios')
                                SafariView.dismiss();
                        }

                    }
                }
                UIA.log(evt)
            });
            var openlink = () => {
                Linking.canOpenURL(loginUrl).then(supported => {
                    return AsyncStorage.setItem(UIA.SIGNED_OUT, 'false').then(() => {
                        if (supported) {
                            UIA.log('supports this link ; ' + loginUrl)
                            Linking.openURL(loginUrl);
                        } else {
                            UIA.log('Don\'t know how to open URI: ' + loginUrl);
                        }
                    });
                });
            };
            if (Platform.OS === 'ios') {
                SafariView.isAvailable()
                    .then(SafariView.show({
                        url: loginUrl
                    }));
            }
            else {
                Linking.getInitialURL().then((url) => {
                    UIA.log('initial url');;
                    UIA.log(url);
                    var accessToken = me.getAccessToken({ url });
                    if (accessToken) {
                        if (this.props.onAuthentification) {
                            console.log('checking if signed out last session')
                            AsyncStorage.getItem(UIA.SIGNED_OUT).then(res => {
                                if (!JSON.parse(res || 'false')) {
                                    me.props.onAuthentification(accessToken);
                                }
                                else {
                                    openlink();
                                }
                            })
                        }
                    }
                    else {
                        openlink();
                    }
                }).catch(err => console.error('An error occurred', err));
            }
        });
    }
    componentWillUnmount() { }
    _loadInitialState = async () => {
        this.setState({
            loggedIn: false,
            loadedCookie: true
        });
    }
    getParmFromHash(navState, parm) {
        var accessToken = null;
        var accesst = '#access_token=';
        if (navState && navState.url) {
            var accessIndex = navState.url.indexOf(accesst);
            if (accessIndex !== -1) {
                var accessIndexEnd = navState.url.indexOf('&');
                accessIndex = accessIndex !== -1 ? accessIndex : navState.url.length;
                accessToken = navState.url.substring(accessIndex + accesst.length, accessIndexEnd);
            }
            UIA.log(`accessToken : ${accessToken}`);
        }
        return accessToken;
    }
    onNavigationStateChange(navState) {
        // If we get redirected back to the HOME_URL we know that we are logged in. 
        // If your backend does something different than this
        // change this line.
        var accessToken = this.getParmFromHash(navState, 'access_token');
        if (accessToken) {
            this.setState({
                loggedIn: true,
                accessToken
            });
            if (this.props.onAuthentification) {
                this.props.onAuthentification(accessToken);
            }
        }
        this.setState({ loginUrl: navState.url })
    }
    getLoginView() {
        var { loginView } = this.props;
        if (loginView) {
            UIA.log('returning loginview');
            return loginView
        }
        return (
            <View>
                <Text>
                    Logged in.
                </Text>
            </View>
        )
    }
    getInitialView() {
        var { initialview } = this.props;
        return initialview || null;
    }
    render() {
        var { loginUrl } = this.props;
        var loginview = this.getLoginView();
        var initialview = this.getInitialView();
        // If we have completed loading the cookie choose to show Login WebView or the LoggedIn component, else just show an empty View.

        return (
            <View>
            </View>
        );
    }
}

const styles = ({
    welcome: {
        fontSize: 20,
        textAlign: 'center',
        margin: 10,
        height: 300,
        width: 200
    },
    webView: {},
    instructions: {
        textAlign: 'center',
        color: '#333333',
        marginBottom: 5,
    },
    container: {
        flex: 1,
        backgroundColor: '#F5FCFF',
        alignSelf: 'stretch',
        alignItems: 'stretch'
    }
});

==> redquicklib-1.500.0.tgz: package/lib/components/reactnativelogin.js <==
'use strict';
import * as UIA from '../actions/uiActions';
import React, { Component } from 'react';
import {
    AppRegistry,
    StyleSheet,
    Text,
    WebView,
    Linking,
    LinkingIOS,
    Platform,
    View,
    AsyncStorage
} from 'react-native';
var libSafariView = require("react-native-safari-view");
var SafariView = libSafariView.default;
import * as Titles from '../titles';
import * as Common from '../common';
// Change these to reflect


export default class ReactNativeLogin extends Component {
    constructor(props) {
        super(props);

        this.state = {
            loggedIn: false,
            loadedCookie: false
        };
    }
    getAccessToken(evt) {
        if (evt && evt.url) {
            var accessToken = evt.url.split('access=')[1];
            return accessToken;
        }
    }
    componentWillMount() {
        var me = this;
        this._loadInitialState();
        this.props.loginUrl().then(loginUrl => {

            UIA.log('adding linking listener');
            Linking.addEventListener('url', (evt) => {
                if (evt && evt.url) {
                    UIA.log(evt.url)
                    this.props.ui('URL_', evt.url);
                    var accessToken = me.getAccessToken(evt); //.url.split('access=')[1];
                    if (accessToken) {
                        if (this.props.onAuthentification) {
                            this.props.onAuthentification(accessToken);
                            if (Platform.OS === 'ios')
                                SafariView.dismiss();
                        }

                    }
                }
                UIA.log(evt)
            });
            var openlink = () => {
                Linking.canOpenURL(loginUrl).then(supported => {
                    return AsyncStorage.setItem(UIA.SIGNED_OUT, 'false').then(() => {
                        if (supported) {
                            UIA.log('supports this link ; ' + loginUrl)
                            Linking.openURL(loginUrl);
                        } else {
                            UIA.log('Don\'t know how to open URI: ' + loginUrl);
                        }
                    });
                });
            };
            if (Platform.OS === 'ios') {
                SafariView.isAvailable()
                    .then(SafariView.show({
                        url: loginUrl
                    }));
            }
            else {
                Linking.getInitialURL().then((url) => {
                    UIA.log('initial url');;
                    UIA.log(url);
                    var accessToken = me.getAccessToken({ url });
                    if (accessToken) {
                        if (this.props.onAuthentification) {
                            console.log('checking if signed out last session')
                            AsyncStorage.getItem(UIA.SIGNED_OUT).then(res => {
                                if (!JSON.parse(res || 'false')) {
                                    me.props.onAuthentification(accessToken);
                                }
                                else {
                                    openlink();
                                }
                            })
                        }
                    }
                    else {
                        openlink();
                    }
                }).catch(err => console.error('An error occurred', err));
            }
        });
    }
    componentWillUnmount() { }
    _loadInitialState = async () => {
        this.setState({
            loggedIn: false,
            loadedCookie: true
        });
    }
    getParmFromHash(navState, parm) {
        var accessToken = null;
        var accesst = '#access_token=';
        if (navState && navState.url) {
            var accessIndex = navState.url.indexOf(accesst);
            if (accessIndex !== -1) {
                var accessIndexEnd = navState.url.indexOf('&');
                accessIndex = accessIndex !== -1 ? accessIndex : navState.url.length;
                accessToken = navState.url.substring(accessIndex + accesst.length, accessIndexEnd);
            }
            UIA.log(`accessToken : ${accessToken}`);
        }
        return accessToken;
    }
    onNavigationStateChange(navState) {
        // If we get redirected back to the HOME_URL we know that we are logged in. 
        // If your backend does something different than this
        // change this line.
        var accessToken = this.getParmFromHash(navState, 'access_token');
        if (accessToken) {
            this.setState({
                loggedIn: true,
                accessToken
            });
            if (this.props.onAuthentification) {
                this.props.onAuthentification(accessToken);
            }
        }
        this.setState({ loginUrl: navState.url })
    }
    getLoginView() {
        var { loginView } = this.props;
        if (loginView) {
            UIA.log('returning loginview');
            return loginView
        }
        return (
            <View>
                <Text>
                    Logged in.
                </Text>
            </View>
        )
    }
    getInitialView() {
        var { initialview } = this.props;
        return initialview || null;
    }
    render() {
        var { loginUrl } = this.props;
        var loginview = this.getLoginView();
        var initialview = this.getInitialView();
        // If we have completed loading the cookie choose to show Login WebView or the LoggedIn component, else just show an empty View.

        return (
            <View>
            </View>
        );
    }
}

const styles = ({
    welcome: {
        fontSize: 20,
        textAlign: 'center',
        margin: 10,
        height: 300,
        width: 200
    },
    webView: {},
    instructions: {
        textAlign: 'center',
        color: '#333333',
        marginBottom: 5,
    },
    container: {
        flex: 1,
        backgroundColor: '#F5FCFF',
        alignSelf: 'stretch',
        alignItems: 'stretch'
    }
});
